Enum rgraph::SolverError [] [src]

pub enum SolverError {
    AssetNotDeclared(String),
    AssetNotProduced(String),
    AssetNotCreated(String),
    AssetWrongType(String),
    AssetUnbound(String),
    NodeNotFound(String),
    NoTerminalsDefined,
    NotImplemented,
}

Errors that may happen during a Solver instance execution

Variants

The asset was never declared during graph construction

A node producing such asset was not declared

The asset was never instantiated during graph execution

The asset trying to retrieve is of a different type. Users of this interface meant to know the name and type of each asset.

the asset in not bound, no connection can be found in the graph that satisfies this asset

No node was found with this name.

The current graph has no terminal nodes (no output)

WIP